# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import enum

import winrt.system
from winrt import _winrt_windows_ui_xaml_automation_peers

__all__ = [
    "AccessibilityView",
    "AutomationControlType",
    "AutomationEvents",
    "AutomationHeadingLevel",
    "AutomationLandmarkType",
    "AutomationLiveSetting",
    "AutomationNavigationDirection",
    "AutomationNotificationKind",
    "AutomationNotificationProcessing",
    "AutomationOrientation",
    "AutomationStructureChangeType",
    "PatternInterface",
    "RawElementProviderRuntimeId",
    "AppBarAutomationPeer",
    "AppBarButtonAutomationPeer",
    "AppBarToggleButtonAutomationPeer",
    "AutoSuggestBoxAutomationPeer",
    "AutomationPeer",
    "AutomationPeerAnnotation",
    "ButtonAutomationPeer",
    "ButtonBaseAutomationPeer",
    "CalendarDatePickerAutomationPeer",
    "CaptureElementAutomationPeer",
    "CheckBoxAutomationPeer",
    "ColorPickerSliderAutomationPeer",
    "ColorSpectrumAutomationPeer",
    "ComboBoxAutomationPeer",
    "ComboBoxItemAutomationPeer",
    "ComboBoxItemDataAutomationPeer",
    "DatePickerAutomationPeer",
    "DatePickerFlyoutPresenterAutomationPeer",
    "FlipViewAutomationPeer",
    "FlipViewItemAutomationPeer",
    "FlipViewItemDataAutomationPeer",
    "FlyoutPresenterAutomationPeer",
    "FrameworkElementAutomationPeer",
    "GridViewAutomationPeer",
    "GridViewHeaderItemAutomationPeer",
    "GridViewItemAutomationPeer",
    "GridViewItemDataAutomationPeer",
    "GroupItemAutomationPeer",
    "HubAutomationPeer",
    "HubSectionAutomationPeer",
    "HyperlinkButtonAutomationPeer",
    "ImageAutomationPeer",
    "InkToolbarAutomationPeer",
    "ItemAutomationPeer",
    "ItemsControlAutomationPeer",
    "ListBoxAutomationPeer",
    "ListBoxItemAutomationPeer",
    "ListBoxItemDataAutomationPeer",
    "ListPickerFlyoutPresenterAutomationPeer",
    "ListViewAutomationPeer",
    "ListViewBaseAutomationPeer",
    "ListViewBaseHeaderItemAutomationPeer",
    "ListViewHeaderItemAutomationPeer",
    "ListViewItemAutomationPeer",
    "ListViewItemDataAutomationPeer",
    "LoopingSelectorAutomationPeer",
    "LoopingSelectorItemAutomationPeer",
    "LoopingSelectorItemDataAutomationPeer",
    "MapControlAutomationPeer",
    "MediaElementAutomationPeer",
    "MediaPlayerElementAutomationPeer",
    "MediaTransportControlsAutomationPeer",
    "MenuBarAutomationPeer",
    "MenuBarItemAutomationPeer",
    "MenuFlyoutItemAutomationPeer",
    "MenuFlyoutPresenterAutomationPeer",
    "NavigationViewItemAutomationPeer",
    "PasswordBoxAutomationPeer",
    "PersonPictureAutomationPeer",
    "PickerFlyoutPresenterAutomationPeer",
    "PivotAutomationPeer",
    "PivotItemAutomationPeer",
    "PivotItemDataAutomationPeer",
    "ProgressBarAutomationPeer",
    "ProgressRingAutomationPeer",
    "RadioButtonAutomationPeer",
    "RangeBaseAutomationPeer",
    "RatingControlAutomationPeer",
    "RepeatButtonAutomationPeer",
    "RichEditBoxAutomationPeer",
    "RichTextBlockAutomationPeer",
    "RichTextBlockOverflowAutomationPeer",
    "ScrollBarAutomationPeer",
    "ScrollViewerAutomationPeer",
    "SearchBoxAutomationPeer",
    "SelectorAutomationPeer",
    "SelectorItemAutomationPeer",
    "SemanticZoomAutomationPeer",
    "SettingsFlyoutAutomationPeer",
    "SliderAutomationPeer",
    "TextBlockAutomationPeer",
    "TextBoxAutomationPeer",
    "ThumbAutomationPeer",
    "TimePickerAutomationPeer",
    "TimePickerFlyoutPresenterAutomationPeer",
    "ToggleButtonAutomationPeer",
    "ToggleMenuFlyoutItemAutomationPeer",
    "ToggleSwitchAutomationPeer",
    "TreeViewItemAutomationPeer",
    "TreeViewListAutomationPeer",
]

class AccessibilityView(enum.IntEnum):
    RAW = 0
    CONTROL = 1
    CONTENT = 2

class AutomationControlType(enum.IntEnum):
    BUTTON = 0
    CALENDAR = 1
    CHECK_BOX = 2
    COMBO_BOX = 3
    EDIT = 4
    HYPERLINK = 5
    IMAGE = 6
    LIST_ITEM = 7
    LIST = 8
    MENU = 9
    MENU_BAR = 10
    MENU_ITEM = 11
    PROGRESS_BAR = 12
    RADIO_BUTTON = 13
    SCROLL_BAR = 14
    SLIDER = 15
    SPINNER = 16
    STATUS_BAR = 17
    TAB = 18
    TAB_ITEM = 19
    TEXT = 20
    TOOL_BAR = 21
    TOOL_TIP = 22
    TREE = 23
    TREE_ITEM = 24
    CUSTOM = 25
    GROUP = 26
    THUMB = 27
    DATA_GRID = 28
    DATA_ITEM = 29
    DOCUMENT = 30
    SPLIT_BUTTON = 31
    WINDOW = 32
    PANE = 33
    HEADER = 34
    HEADER_ITEM = 35
    TABLE = 36
    TITLE_BAR = 37
    SEPARATOR = 38
    SEMANTIC_ZOOM = 39
    APP_BAR = 40

class AutomationEvents(enum.IntEnum):
    TOOL_TIP_OPENED = 0
    TOOL_TIP_CLOSED = 1
    MENU_OPENED = 2
    MENU_CLOSED = 3
    AUTOMATION_FOCUS_CHANGED = 4
    INVOKE_PATTERN_ON_INVOKED = 5
    SELECTION_ITEM_PATTERN_ON_ELEMENT_ADDED_TO_SELECTION = 6
    SELECTION_ITEM_PATTERN_ON_ELEMENT_REMOVED_FROM_SELECTION = 7
    SELECTION_ITEM_PATTERN_ON_ELEMENT_SELECTED = 8
    SELECTION_PATTERN_ON_INVALIDATED = 9
    TEXT_PATTERN_ON_TEXT_SELECTION_CHANGED = 10
    TEXT_PATTERN_ON_TEXT_CHANGED = 11
    ASYNC_CONTENT_LOADED = 12
    PROPERTY_CHANGED = 13
    STRUCTURE_CHANGED = 14
    DRAG_START = 15
    DRAG_CANCEL = 16
    DRAG_COMPLETE = 17
    DRAG_ENTER = 18
    DRAG_LEAVE = 19
    DROPPED = 20
    LIVE_REGION_CHANGED = 21
    INPUT_REACHED_TARGET = 22
    INPUT_REACHED_OTHER_ELEMENT = 23
    INPUT_DISCARDED = 24
    WINDOW_CLOSED = 25
    WINDOW_OPENED = 26
    CONVERSION_TARGET_CHANGED = 27
    TEXT_EDIT_TEXT_CHANGED = 28
    LAYOUT_INVALIDATED = 29

class AutomationHeadingLevel(enum.IntEnum):
    NONE = 0
    LEVEL1 = 1
    LEVEL2 = 2
    LEVEL3 = 3
    LEVEL4 = 4
    LEVEL5 = 5
    LEVEL6 = 6
    LEVEL7 = 7
    LEVEL8 = 8
    LEVEL9 = 9

class AutomationLandmarkType(enum.IntEnum):
    NONE = 0
    CUSTOM = 1
    FORM = 2
    MAIN = 3
    NAVIGATION = 4
    SEARCH = 5

class AutomationLiveSetting(enum.IntEnum):
    OFF = 0
    POLITE = 1
    ASSERTIVE = 2

class AutomationNavigationDirection(enum.IntEnum):
    PARENT = 0
    NEXT_SIBLING = 1
    PREVIOUS_SIBLING = 2
    FIRST_CHILD = 3
    LAST_CHILD = 4

class AutomationNotificationKind(enum.IntEnum):
    ITEM_ADDED = 0
    ITEM_REMOVED = 1
    ACTION_COMPLETED = 2
    ACTION_ABORTED = 3
    OTHER = 4

class AutomationNotificationProcessing(enum.IntEnum):
    IMPORTANT_ALL = 0
    IMPORTANT_MOST_RECENT = 1
    ALL = 2
    MOST_RECENT = 3
    CURRENT_THEN_MOST_RECENT = 4

class AutomationOrientation(enum.IntEnum):
    NONE = 0
    HORIZONTAL = 1
    VERTICAL = 2

class AutomationStructureChangeType(enum.IntEnum):
    CHILD_ADDED = 0
    CHILD_REMOVED = 1
    CHILDREN_INVALIDATED = 2
    CHILDREN_BULK_ADDED = 3
    CHILDREN_BULK_REMOVED = 4
    CHILDREN_REORDERED = 5

class PatternInterface(enum.IntEnum):
    INVOKE = 0
    SELECTION = 1
    VALUE = 2
    RANGE_VALUE = 3
    SCROLL = 4
    SCROLL_ITEM = 5
    EXPAND_COLLAPSE = 6
    GRID = 7
    GRID_ITEM = 8
    MULTIPLE_VIEW = 9
    WINDOW = 10
    SELECTION_ITEM = 11
    DOCK = 12
    TABLE = 13
    TABLE_ITEM = 14
    TOGGLE = 15
    TRANSFORM = 16
    TEXT = 17
    ITEM_CONTAINER = 18
    VIRTUALIZED_ITEM = 19
    TEXT2 = 20
    TEXT_CHILD = 21
    TEXT_RANGE = 22
    ANNOTATION = 23
    DRAG = 24
    DROP_TARGET = 25
    OBJECT_MODEL = 26
    SPREADSHEET = 27
    SPREADSHEET_ITEM = 28
    STYLES = 29
    TRANSFORM2 = 30
    SYNCHRONIZED_INPUT = 31
    TEXT_EDIT = 32
    CUSTOM_NAVIGATION = 33

RawElementProviderRuntimeId = _winrt_windows_ui_xaml_automation_peers.RawElementProviderRuntimeId
AppBarAutomationPeer = _winrt_windows_ui_xaml_automation_peers.AppBarAutomationPeer
AppBarButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.AppBarButtonAutomationPeer
AppBarToggleButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.AppBarToggleButtonAutomationPeer
AutoSuggestBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.AutoSuggestBoxAutomationPeer
AutomationPeer = _winrt_windows_ui_xaml_automation_peers.AutomationPeer
AutomationPeerAnnotation = _winrt_windows_ui_xaml_automation_peers.AutomationPeerAnnotation
ButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ButtonAutomationPeer
ButtonBaseAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ButtonBaseAutomationPeer
CalendarDatePickerAutomationPeer = _winrt_windows_ui_xaml_automation_peers.CalendarDatePickerAutomationPeer
CaptureElementAutomationPeer = _winrt_windows_ui_xaml_automation_peers.CaptureElementAutomationPeer
CheckBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.CheckBoxAutomationPeer
ColorPickerSliderAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ColorPickerSliderAutomationPeer
ColorSpectrumAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ColorSpectrumAutomationPeer
ComboBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ComboBoxAutomationPeer
ComboBoxItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ComboBoxItemAutomationPeer
ComboBoxItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ComboBoxItemDataAutomationPeer
DatePickerAutomationPeer = _winrt_windows_ui_xaml_automation_peers.DatePickerAutomationPeer
DatePickerFlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.DatePickerFlyoutPresenterAutomationPeer
FlipViewAutomationPeer = _winrt_windows_ui_xaml_automation_peers.FlipViewAutomationPeer
FlipViewItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.FlipViewItemAutomationPeer
FlipViewItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.FlipViewItemDataAutomationPeer
FlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.FlyoutPresenterAutomationPeer
FrameworkElementAutomationPeer = _winrt_windows_ui_xaml_automation_peers.FrameworkElementAutomationPeer
GridViewAutomationPeer = _winrt_windows_ui_xaml_automation_peers.GridViewAutomationPeer
GridViewHeaderItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.GridViewHeaderItemAutomationPeer
GridViewItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.GridViewItemAutomationPeer
GridViewItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.GridViewItemDataAutomationPeer
GroupItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.GroupItemAutomationPeer
HubAutomationPeer = _winrt_windows_ui_xaml_automation_peers.HubAutomationPeer
HubSectionAutomationPeer = _winrt_windows_ui_xaml_automation_peers.HubSectionAutomationPeer
HyperlinkButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.HyperlinkButtonAutomationPeer
ImageAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ImageAutomationPeer
InkToolbarAutomationPeer = _winrt_windows_ui_xaml_automation_peers.InkToolbarAutomationPeer
ItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ItemAutomationPeer
ItemsControlAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ItemsControlAutomationPeer
ListBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListBoxAutomationPeer
ListBoxItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListBoxItemAutomationPeer
ListBoxItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListBoxItemDataAutomationPeer
ListPickerFlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListPickerFlyoutPresenterAutomationPeer
ListViewAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewAutomationPeer
ListViewBaseAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewBaseAutomationPeer
ListViewBaseHeaderItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewBaseHeaderItemAutomationPeer
ListViewHeaderItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewHeaderItemAutomationPeer
ListViewItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewItemAutomationPeer
ListViewItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ListViewItemDataAutomationPeer
LoopingSelectorAutomationPeer = _winrt_windows_ui_xaml_automation_peers.LoopingSelectorAutomationPeer
LoopingSelectorItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.LoopingSelectorItemAutomationPeer
LoopingSelectorItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.LoopingSelectorItemDataAutomationPeer
MapControlAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MapControlAutomationPeer
MediaElementAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MediaElementAutomationPeer
MediaPlayerElementAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MediaPlayerElementAutomationPeer
MediaTransportControlsAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MediaTransportControlsAutomationPeer
MenuBarAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MenuBarAutomationPeer
MenuBarItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MenuBarItemAutomationPeer
MenuFlyoutItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MenuFlyoutItemAutomationPeer
MenuFlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.MenuFlyoutPresenterAutomationPeer
NavigationViewItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.NavigationViewItemAutomationPeer
PasswordBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PasswordBoxAutomationPeer
PersonPictureAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PersonPictureAutomationPeer
PickerFlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PickerFlyoutPresenterAutomationPeer
PivotAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PivotAutomationPeer
PivotItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PivotItemAutomationPeer
PivotItemDataAutomationPeer = _winrt_windows_ui_xaml_automation_peers.PivotItemDataAutomationPeer
ProgressBarAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ProgressBarAutomationPeer
ProgressRingAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ProgressRingAutomationPeer
RadioButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RadioButtonAutomationPeer
RangeBaseAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RangeBaseAutomationPeer
RatingControlAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RatingControlAutomationPeer
RepeatButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RepeatButtonAutomationPeer
RichEditBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RichEditBoxAutomationPeer
RichTextBlockAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RichTextBlockAutomationPeer
RichTextBlockOverflowAutomationPeer = _winrt_windows_ui_xaml_automation_peers.RichTextBlockOverflowAutomationPeer
ScrollBarAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ScrollBarAutomationPeer
ScrollViewerAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ScrollViewerAutomationPeer
SearchBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SearchBoxAutomationPeer
SelectorAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SelectorAutomationPeer
SelectorItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SelectorItemAutomationPeer
SemanticZoomAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SemanticZoomAutomationPeer
SettingsFlyoutAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SettingsFlyoutAutomationPeer
SliderAutomationPeer = _winrt_windows_ui_xaml_automation_peers.SliderAutomationPeer
TextBlockAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TextBlockAutomationPeer
TextBoxAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TextBoxAutomationPeer
ThumbAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ThumbAutomationPeer
TimePickerAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TimePickerAutomationPeer
TimePickerFlyoutPresenterAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TimePickerFlyoutPresenterAutomationPeer
ToggleButtonAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ToggleButtonAutomationPeer
ToggleMenuFlyoutItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ToggleMenuFlyoutItemAutomationPeer
ToggleSwitchAutomationPeer = _winrt_windows_ui_xaml_automation_peers.ToggleSwitchAutomationPeer
TreeViewItemAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TreeViewItemAutomationPeer
TreeViewListAutomationPeer = _winrt_windows_ui_xaml_automation_peers.TreeViewListAutomationPeer



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.foundation.collections
import winrt.windows.ui.xaml
import winrt.windows.ui.xaml.automation
import winrt.windows.ui.xaml.automation.provider
import winrt.windows.ui.xaml.controls
import winrt.windows.ui.xaml.controls.primitives

from winrt.windows.ui.xaml.automation.peers import AccessibilityView, AutomationControlType, AutomationEvents, AutomationHeadingLevel, AutomationLandmarkType, AutomationLiveSetting, AutomationNavigationDirection, AutomationNotificationKind, AutomationNotificationProcessing, AutomationOrientation, AutomationStructureChangeType, PatternInterface

Self = typing.TypeVar('Self')

class RawElementProviderRuntimeId:
    part1: winrt.system.UInt32
    part2: winrt.system.UInt32
    def __init__(self, part1: winrt.system.UInt32, part2: winrt.system.UInt32) -> None: ...

class AppBarAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarAutomationPeer: ...
    def __new__(cls: typing.Type[AppBarAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.AppBar]) -> AppBarAutomationPeer:...
    def close(self) -> None: ...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    def set_visual_state(self, state: winrt.windows.ui.xaml.automation.WindowVisualState, /) -> None: ...
    def toggle(self) -> None: ...
    def wait_for_input_idle(self, milliseconds: winrt.system.Int32, /) -> bool: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...
    @_property
    def toggle_state(self) -> winrt.windows.ui.xaml.automation.ToggleState: ...
    @_property
    def interaction_state(self) -> winrt.windows.ui.xaml.automation.WindowInteractionState: ...
    @_property
    def is_modal(self) -> bool: ...
    @_property
    def is_topmost(self) -> bool: ...
    @_property
    def maximizable(self) -> bool: ...
    @_property
    def minimizable(self) -> bool: ...
    @_property
    def visual_state(self) -> winrt.windows.ui.xaml.automation.WindowVisualState: ...

class AppBarButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarButtonAutomationPeer: ...
    def __new__(cls: typing.Type[AppBarButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.AppBarButton]) -> AppBarButtonAutomationPeer:...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...

class AppBarToggleButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarToggleButtonAutomationPeer: ...
    def __new__(cls: typing.Type[AppBarToggleButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.AppBarToggleButton]) -> AppBarToggleButtonAutomationPeer:...

class AutoSuggestBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AutoSuggestBoxAutomationPeer: ...
    def __new__(cls: typing.Type[AutoSuggestBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.AutoSuggestBox]) -> AutoSuggestBoxAutomationPeer:...
    def invoke(self) -> None: ...

class AutomationPeer_Static(type):
    def generate_raw_element_provider_runtime_id(cls) -> RawElementProviderRuntimeId: ...
    def listener_exists(cls, event_id: AutomationEvents, /) -> bool: ...

class AutomationPeer(winrt.system.Object, metaclass=AutomationPeer_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AutomationPeer: ...
    def get_accelerator_key(self) -> str: ...
    def get_accelerator_key_core(self) -> str: ...
    def get_access_key(self) -> str: ...
    def get_access_key_core(self) -> str: ...
    def get_annotations(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[AutomationPeerAnnotation]]: ...
    def get_annotations_core(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[AutomationPeerAnnotation]]: ...
    def get_automation_control_type(self) -> AutomationControlType: ...
    def get_automation_control_type_core(self) -> AutomationControlType: ...
    def get_automation_id(self) -> str: ...
    def get_automation_id_core(self) -> str: ...
    def get_bounding_rectangle(self) -> winrt.windows.foundation.Rect: ...
    def get_bounding_rectangle_core(self) -> winrt.windows.foundation.Rect: ...
    def get_children(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[AutomationPeer]]: ...
    def get_children_core(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[AutomationPeer]]: ...
    def get_class_name(self) -> str: ...
    def get_class_name_core(self) -> str: ...
    def get_clickable_point(self) -> winrt.windows.foundation.Point: ...
    def get_clickable_point_core(self) -> winrt.windows.foundation.Point: ...
    def get_controlled_peers(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[AutomationPeer]]: ...
    def get_controlled_peers_core(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[AutomationPeer]]: ...
    def get_culture(self) -> winrt.system.Int32: ...
    def get_culture_core(self) -> winrt.system.Int32: ...
    def get_described_by_core(self) -> typing.Optional[winrt.windows.foundation.collections.IIterable[AutomationPeer]]: ...
    def get_element_from_point(self, point_in_window_coordinates: winrt.windows.foundation.Point, /) -> typing.Optional[winrt.system.Object]: ...
    def get_element_from_point_core(self, point_in_window_coordinates: winrt.windows.foundation.Point, /) -> typing.Optional[winrt.system.Object]: ...
    def get_flows_from_core(self) -> typing.Optional[winrt.windows.foundation.collections.IIterable[AutomationPeer]]: ...
    def get_flows_to_core(self) -> typing.Optional[winrt.windows.foundation.collections.IIterable[AutomationPeer]]: ...
    def get_focused_element(self) -> typing.Optional[winrt.system.Object]: ...
    def get_focused_element_core(self) -> typing.Optional[winrt.system.Object]: ...
    def get_full_description(self) -> str: ...
    def get_full_description_core(self) -> str: ...
    def get_heading_level(self) -> AutomationHeadingLevel: ...
    def get_heading_level_core(self) -> AutomationHeadingLevel: ...
    def get_help_text(self) -> str: ...
    def get_help_text_core(self) -> str: ...
    def get_item_status(self) -> str: ...
    def get_item_status_core(self) -> str: ...
    def get_item_type(self) -> str: ...
    def get_item_type_core(self) -> str: ...
    def get_labeled_by(self) -> typing.Optional[AutomationPeer]: ...
    def get_labeled_by_core(self) -> typing.Optional[AutomationPeer]: ...
    def get_landmark_type(self) -> AutomationLandmarkType: ...
    def get_landmark_type_core(self) -> AutomationLandmarkType: ...
    def get_level(self) -> winrt.system.Int32: ...
    def get_level_core(self) -> winrt.system.Int32: ...
    def get_live_setting(self) -> AutomationLiveSetting: ...
    def get_live_setting_core(self) -> AutomationLiveSetting: ...
    def get_localized_control_type(self) -> str: ...
    def get_localized_control_type_core(self) -> str: ...
    def get_localized_landmark_type(self) -> str: ...
    def get_localized_landmark_type_core(self) -> str: ...
    def get_name(self) -> str: ...
    def get_name_core(self) -> str: ...
    def get_orientation(self) -> AutomationOrientation: ...
    def get_orientation_core(self) -> AutomationOrientation: ...
    def get_parent(self) -> typing.Optional[AutomationPeer]: ...
    def get_pattern(self, pattern_interface: PatternInterface, /) -> typing.Optional[winrt.system.Object]: ...
    def get_pattern_core(self, pattern_interface: PatternInterface, /) -> typing.Optional[winrt.system.Object]: ...
    def get_peer_from_point(self, point: winrt.windows.foundation.Point, /) -> typing.Optional[AutomationPeer]: ...
    def get_peer_from_point_core(self, point: winrt.windows.foundation.Point, /) -> typing.Optional[AutomationPeer]: ...
    def get_position_in_set(self) -> winrt.system.Int32: ...
    def get_position_in_set_core(self) -> winrt.system.Int32: ...
    def get_size_of_set(self) -> winrt.system.Int32: ...
    def get_size_of_set_core(self) -> winrt.system.Int32: ...
    def has_keyboard_focus(self) -> bool: ...
    def has_keyboard_focus_core(self) -> bool: ...
    def invalidate_peer(self) -> None: ...
    def is_content_element(self) -> bool: ...
    def is_content_element_core(self) -> bool: ...
    def is_control_element(self) -> bool: ...
    def is_control_element_core(self) -> bool: ...
    def is_data_valid_for_form(self) -> bool: ...
    def is_data_valid_for_form_core(self) -> bool: ...
    def is_dialog(self) -> bool: ...
    def is_dialog_core(self) -> bool: ...
    def is_enabled(self) -> bool: ...
    def is_enabled_core(self) -> bool: ...
    def is_keyboard_focusable(self) -> bool: ...
    def is_keyboard_focusable_core(self) -> bool: ...
    def is_offscreen(self) -> bool: ...
    def is_offscreen_core(self) -> bool: ...
    def is_password(self) -> bool: ...
    def is_password_core(self) -> bool: ...
    def is_peripheral(self) -> bool: ...
    def is_peripheral_core(self) -> bool: ...
    def is_required_for_form(self) -> bool: ...
    def is_required_for_form_core(self) -> bool: ...
    def navigate(self, direction: AutomationNavigationDirection, /) -> typing.Optional[winrt.system.Object]: ...
    def navigate_core(self, direction: AutomationNavigationDirection, /) -> typing.Optional[winrt.system.Object]: ...
    def peer_from_provider(self, provider: typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple], /) -> typing.Optional[AutomationPeer]: ...
    def provider_from_peer(self, peer: typing.Optional[AutomationPeer], /) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    def raise_automation_event(self, event_id: AutomationEvents, /) -> None: ...
    def raise_notification_event(self, notification_kind: AutomationNotificationKind, notification_processing: AutomationNotificationProcessing, display_string: str, activity_id: str, /) -> None: ...
    def raise_property_changed_event(self, automation_property: typing.Optional[winrt.windows.ui.xaml.automation.AutomationProperty], old_value: typing.Optional[winrt.system.Object], new_value: typing.Optional[winrt.system.Object], /) -> None: ...
    def raise_structure_changed_event(self, structure_change_type: AutomationStructureChangeType, child: typing.Optional[AutomationPeer], /) -> None: ...
    def raise_text_edit_text_changed_event(self, automation_text_edit_change_type: winrt.windows.ui.xaml.automation.AutomationTextEditChangeType, changed_data: winrt.windows.foundation.collections.IVectorView[str], /) -> None: ...
    def set_focus(self) -> None: ...
    def set_focus_core(self) -> None: ...
    def set_parent(self, peer: typing.Optional[AutomationPeer], /) -> None: ...
    def show_context_menu(self) -> None: ...
    def show_context_menu_core(self) -> None: ...
    @_property
    def events_source(self) -> typing.Optional[AutomationPeer]: ...
    @events_source.setter
    def events_source(self, value: typing.Optional[AutomationPeer]) -> None: ...

class AutomationPeerAnnotation_Static(type):
    @_property
    def peer_property(cls) -> typing.Optional[winrt.windows.ui.xaml.DependencyProperty]: ...
    @_property
    def type_property(cls) -> typing.Optional[winrt.windows.ui.xaml.DependencyProperty]: ...

class AutomationPeerAnnotation(winrt.system.Object, metaclass=AutomationPeerAnnotation_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AutomationPeerAnnotation: ...
    @typing.overload
    def __new__(cls: typing.Type[AutomationPeerAnnotation], type: winrt.windows.ui.xaml.automation.AnnotationType) -> AutomationPeerAnnotation:...
    @typing.overload
    def __new__(cls: typing.Type[AutomationPeerAnnotation], type: winrt.windows.ui.xaml.automation.AnnotationType, peer: typing.Optional[AutomationPeer]) -> AutomationPeerAnnotation:...
    @typing.overload
    def __new__(cls: typing.Type[AutomationPeerAnnotation]) -> AutomationPeerAnnotation:...
    @_property
    def type(self) -> winrt.windows.ui.xaml.automation.AnnotationType: ...
    @type.setter
    def type(self, value: winrt.windows.ui.xaml.automation.AnnotationType) -> None: ...
    @_property
    def peer(self) -> typing.Optional[AutomationPeer]: ...
    @peer.setter
    def peer(self, value: typing.Optional[AutomationPeer]) -> None: ...

class ButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ButtonAutomationPeer: ...
    def __new__(cls: typing.Type[ButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.Button]) -> ButtonAutomationPeer:...
    def invoke(self) -> None: ...

class ButtonBaseAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ButtonBaseAutomationPeer: ...

class CalendarDatePickerAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CalendarDatePickerAutomationPeer: ...
    def __new__(cls: typing.Type[CalendarDatePickerAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.CalendarDatePicker]) -> CalendarDatePickerAutomationPeer:...
    def invoke(self) -> None: ...
    def set_value(self, value: str, /) -> None: ...
    @_property
    def is_read_only(self) -> bool: ...
    @_property
    def value(self) -> str: ...

class CaptureElementAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CaptureElementAutomationPeer: ...
    def __new__(cls: typing.Type[CaptureElementAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.CaptureElement]) -> CaptureElementAutomationPeer:...

class CheckBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CheckBoxAutomationPeer: ...
    def __new__(cls: typing.Type[CheckBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.CheckBox]) -> CheckBoxAutomationPeer:...

class ColorPickerSliderAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ColorPickerSliderAutomationPeer: ...
    def __new__(cls: typing.Type[ColorPickerSliderAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.ColorPickerSlider]) -> ColorPickerSliderAutomationPeer:...

class ColorSpectrumAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ColorSpectrumAutomationPeer: ...
    def __new__(cls: typing.Type[ColorSpectrumAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.ColorSpectrum]) -> ColorSpectrumAutomationPeer:...

class ComboBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ComboBoxAutomationPeer: ...
    def __new__(cls: typing.Type[ComboBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ComboBox]) -> ComboBoxAutomationPeer:...
    def close(self) -> None: ...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    def set_value(self, value: str, /) -> None: ...
    def set_visual_state(self, state: winrt.windows.ui.xaml.automation.WindowVisualState, /) -> None: ...
    def wait_for_input_idle(self, milliseconds: winrt.system.Int32, /) -> bool: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...
    @_property
    def is_read_only(self) -> bool: ...
    @_property
    def value(self) -> str: ...
    @_property
    def interaction_state(self) -> winrt.windows.ui.xaml.automation.WindowInteractionState: ...
    @_property
    def is_modal(self) -> bool: ...
    @_property
    def is_topmost(self) -> bool: ...
    @_property
    def maximizable(self) -> bool: ...
    @_property
    def minimizable(self) -> bool: ...
    @_property
    def visual_state(self) -> winrt.windows.ui.xaml.automation.WindowVisualState: ...

class ComboBoxItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ComboBoxItemAutomationPeer: ...
    def __new__(cls: typing.Type[ComboBoxItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ComboBoxItem]) -> ComboBoxItemAutomationPeer:...

class ComboBoxItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ComboBoxItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[ComboBoxItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[ComboBoxAutomationPeer]) -> ComboBoxItemDataAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class DatePickerAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DatePickerAutomationPeer: ...
    def __new__(cls: typing.Type[DatePickerAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.DatePicker]) -> DatePickerAutomationPeer:...

class DatePickerFlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DatePickerFlyoutPresenterAutomationPeer: ...

class FlipViewAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlipViewAutomationPeer: ...
    def __new__(cls: typing.Type[FlipViewAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.FlipView]) -> FlipViewAutomationPeer:...

class FlipViewItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlipViewItemAutomationPeer: ...
    def __new__(cls: typing.Type[FlipViewItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.FlipViewItem]) -> FlipViewItemAutomationPeer:...

class FlipViewItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlipViewItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[FlipViewItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[FlipViewAutomationPeer]) -> FlipViewItemDataAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class FlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlyoutPresenterAutomationPeer: ...
    def __new__(cls: typing.Type[FlyoutPresenterAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.FlyoutPresenter]) -> FlyoutPresenterAutomationPeer:...

class FrameworkElementAutomationPeer_Static(type):
    def create_peer_for_element(cls, element: typing.Optional[winrt.windows.ui.xaml.UIElement], /) -> typing.Optional[AutomationPeer]: ...
    def from_element(cls, element: typing.Optional[winrt.windows.ui.xaml.UIElement], /) -> typing.Optional[AutomationPeer]: ...

class FrameworkElementAutomationPeer(winrt.system.Object, metaclass=FrameworkElementAutomationPeer_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FrameworkElementAutomationPeer: ...
    def __new__(cls: typing.Type[FrameworkElementAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.FrameworkElement]) -> FrameworkElementAutomationPeer:...
    @_property
    def owner(self) -> typing.Optional[winrt.windows.ui.xaml.UIElement]: ...

class GridViewAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewAutomationPeer: ...
    def __new__(cls: typing.Type[GridViewAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.GridView]) -> GridViewAutomationPeer:...

class GridViewHeaderItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewHeaderItemAutomationPeer: ...
    def __new__(cls: typing.Type[GridViewHeaderItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.GridViewHeaderItem]) -> GridViewHeaderItemAutomationPeer:...

class GridViewItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewItemAutomationPeer: ...
    def __new__(cls: typing.Type[GridViewItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.GridViewItem]) -> GridViewItemAutomationPeer:...

class GridViewItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[GridViewItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[GridViewAutomationPeer]) -> GridViewItemDataAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class GroupItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GroupItemAutomationPeer: ...
    def __new__(cls: typing.Type[GroupItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.GroupItem]) -> GroupItemAutomationPeer:...

class HubAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> HubAutomationPeer: ...
    def __new__(cls: typing.Type[HubAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.Hub]) -> HubAutomationPeer:...

class HubSectionAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> HubSectionAutomationPeer: ...
    def __new__(cls: typing.Type[HubSectionAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.HubSection]) -> HubSectionAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class HyperlinkButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> HyperlinkButtonAutomationPeer: ...
    def __new__(cls: typing.Type[HyperlinkButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.HyperlinkButton]) -> HyperlinkButtonAutomationPeer:...
    def invoke(self) -> None: ...

class ImageAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ImageAutomationPeer: ...
    def __new__(cls: typing.Type[ImageAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.Image]) -> ImageAutomationPeer:...

class InkToolbarAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> InkToolbarAutomationPeer: ...

class ItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ItemAutomationPeer: ...
    def __new__(cls: typing.Type[ItemAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[ItemsControlAutomationPeer]) -> ItemAutomationPeer:...
    def realize(self) -> None: ...
    @_property
    def item(self) -> typing.Optional[winrt.system.Object]: ...
    @_property
    def items_control_automation_peer(self) -> typing.Optional[ItemsControlAutomationPeer]: ...

class ItemsControlAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ItemsControlAutomationPeer: ...
    def __new__(cls: typing.Type[ItemsControlAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ItemsControl]) -> ItemsControlAutomationPeer:...
    def create_item_automation_peer(self, item: typing.Optional[winrt.system.Object], /) -> typing.Optional[ItemAutomationPeer]: ...
    def find_item_by_property(self, start_after: typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple], automation_property: typing.Optional[winrt.windows.ui.xaml.automation.AutomationProperty], value: typing.Optional[winrt.system.Object], /) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    def on_create_item_automation_peer(self, item: typing.Optional[winrt.system.Object], /) -> typing.Optional[ItemAutomationPeer]: ...

class ListBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListBoxAutomationPeer: ...
    def __new__(cls: typing.Type[ListBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListBox]) -> ListBoxAutomationPeer:...

class ListBoxItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListBoxItemAutomationPeer: ...
    def __new__(cls: typing.Type[ListBoxItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListBoxItem]) -> ListBoxItemAutomationPeer:...

class ListBoxItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListBoxItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[ListBoxItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[ListBoxAutomationPeer]) -> ListBoxItemDataAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class ListPickerFlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListPickerFlyoutPresenterAutomationPeer: ...

class ListViewAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewAutomationPeer: ...
    def __new__(cls: typing.Type[ListViewAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListView]) -> ListViewAutomationPeer:...

class ListViewBaseAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewBaseAutomationPeer: ...
    def __new__(cls: typing.Type[ListViewBaseAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListViewBase]) -> ListViewBaseAutomationPeer:...
    @_property
    def drop_effect(self) -> str: ...
    @_property
    def drop_effects(self) -> str: ...

class ListViewBaseHeaderItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewBaseHeaderItemAutomationPeer: ...

class ListViewHeaderItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewHeaderItemAutomationPeer: ...
    def __new__(cls: typing.Type[ListViewHeaderItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListViewHeaderItem]) -> ListViewHeaderItemAutomationPeer:...

class ListViewItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewItemAutomationPeer: ...
    def __new__(cls: typing.Type[ListViewItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ListViewItem]) -> ListViewItemAutomationPeer:...

class ListViewItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[ListViewItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[ListViewBaseAutomationPeer]) -> ListViewItemDataAutomationPeer:...
    def scroll_into_view(self) -> None: ...

class LoopingSelectorAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelectorAutomationPeer: ...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    def find_item_by_property(self, start_after: typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple], automation_property: typing.Optional[winrt.windows.ui.xaml.automation.AutomationProperty], value: typing.Optional[winrt.system.Object], /) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    def get_selection(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    def scroll(self, horizontal_amount: winrt.windows.ui.xaml.automation.ScrollAmount, vertical_amount: winrt.windows.ui.xaml.automation.ScrollAmount, /) -> None: ...
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    @_property
    def horizontally_scrollable(self) -> bool: ...
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    @_property
    def vertically_scrollable(self) -> bool: ...
    @_property
    def can_select_multiple(self) -> bool: ...
    @_property
    def is_selection_required(self) -> bool: ...

class LoopingSelectorItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelectorItemAutomationPeer: ...
    def add_to_selection(self) -> None: ...
    def remove_from_selection(self) -> None: ...
    def scroll_into_view(self) -> None: ...
    def select(self) -> None: ...
    @_property
    def is_selected(self) -> bool: ...
    @_property
    def selection_container(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...

class LoopingSelectorItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelectorItemDataAutomationPeer: ...
    def realize(self) -> None: ...

class MapControlAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MapControlAutomationPeer: ...
    def move(self, x: winrt.system.Double, y: winrt.system.Double, /) -> None: ...
    def resize(self, width: winrt.system.Double, height: winrt.system.Double, /) -> None: ...
    def rotate(self, degrees: winrt.system.Double, /) -> None: ...
    def scroll(self, horizontal_amount: winrt.windows.ui.xaml.automation.ScrollAmount, vertical_amount: winrt.windows.ui.xaml.automation.ScrollAmount, /) -> None: ...
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    def zoom(self, zoom: winrt.system.Double, /) -> None: ...
    def zoom_by_unit(self, zoom_unit: winrt.windows.ui.xaml.automation.ZoomUnit, /) -> None: ...
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    @_property
    def horizontally_scrollable(self) -> bool: ...
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    @_property
    def vertically_scrollable(self) -> bool: ...
    @_property
    def can_move(self) -> bool: ...
    @_property
    def can_resize(self) -> bool: ...
    @_property
    def can_rotate(self) -> bool: ...
    @_property
    def can_zoom(self) -> bool: ...
    @_property
    def max_zoom(self) -> winrt.system.Double: ...
    @_property
    def min_zoom(self) -> winrt.system.Double: ...
    @_property
    def zoom_level(self) -> winrt.system.Double: ...

class MediaElementAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MediaElementAutomationPeer: ...
    def __new__(cls: typing.Type[MediaElementAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MediaElement]) -> MediaElementAutomationPeer:...

class MediaPlayerElementAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MediaPlayerElementAutomationPeer: ...
    def __new__(cls: typing.Type[MediaPlayerElementAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MediaPlayerElement]) -> MediaPlayerElementAutomationPeer:...

class MediaTransportControlsAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MediaTransportControlsAutomationPeer: ...
    def __new__(cls: typing.Type[MediaTransportControlsAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MediaTransportControls]) -> MediaTransportControlsAutomationPeer:...

class MenuBarAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuBarAutomationPeer: ...
    def __new__(cls: typing.Type[MenuBarAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MenuBar]) -> MenuBarAutomationPeer:...

class MenuBarItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuBarItemAutomationPeer: ...
    def __new__(cls: typing.Type[MenuBarItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MenuBarItem]) -> MenuBarItemAutomationPeer:...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    def invoke(self) -> None: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...

class MenuFlyoutItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuFlyoutItemAutomationPeer: ...
    def __new__(cls: typing.Type[MenuFlyoutItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MenuFlyoutItem]) -> MenuFlyoutItemAutomationPeer:...
    def invoke(self) -> None: ...

class MenuFlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuFlyoutPresenterAutomationPeer: ...
    def __new__(cls: typing.Type[MenuFlyoutPresenterAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.MenuFlyoutPresenter]) -> MenuFlyoutPresenterAutomationPeer:...

class NavigationViewItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> NavigationViewItemAutomationPeer: ...
    def __new__(cls: typing.Type[NavigationViewItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.NavigationViewItem]) -> NavigationViewItemAutomationPeer:...

class PasswordBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PasswordBoxAutomationPeer: ...
    def __new__(cls: typing.Type[PasswordBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.PasswordBox]) -> PasswordBoxAutomationPeer:...

class PersonPictureAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PersonPictureAutomationPeer: ...
    def __new__(cls: typing.Type[PersonPictureAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.PersonPicture]) -> PersonPictureAutomationPeer:...

class PickerFlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PickerFlyoutPresenterAutomationPeer: ...

class PivotAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotAutomationPeer: ...
    def __new__(cls: typing.Type[PivotAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.Pivot]) -> PivotAutomationPeer:...
    def get_selection(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    def scroll(self, horizontal_amount: winrt.windows.ui.xaml.automation.ScrollAmount, vertical_amount: winrt.windows.ui.xaml.automation.ScrollAmount, /) -> None: ...
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    @_property
    def horizontally_scrollable(self) -> bool: ...
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    @_property
    def vertically_scrollable(self) -> bool: ...
    @_property
    def can_select_multiple(self) -> bool: ...
    @_property
    def is_selection_required(self) -> bool: ...

class PivotItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotItemAutomationPeer: ...
    def __new__(cls: typing.Type[PivotItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.PivotItem]) -> PivotItemAutomationPeer:...

class PivotItemDataAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotItemDataAutomationPeer: ...
    def __new__(cls: typing.Type[PivotItemDataAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[PivotAutomationPeer]) -> PivotItemDataAutomationPeer:...
    def add_to_selection(self) -> None: ...
    def realize(self) -> None: ...
    def remove_from_selection(self) -> None: ...
    def scroll_into_view(self) -> None: ...
    def select(self) -> None: ...
    @_property
    def is_selected(self) -> bool: ...
    @_property
    def selection_container(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...

class ProgressBarAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ProgressBarAutomationPeer: ...
    def __new__(cls: typing.Type[ProgressBarAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ProgressBar]) -> ProgressBarAutomationPeer:...

class ProgressRingAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ProgressRingAutomationPeer: ...
    def __new__(cls: typing.Type[ProgressRingAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ProgressRing]) -> ProgressRingAutomationPeer:...

class RadioButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RadioButtonAutomationPeer: ...
    def __new__(cls: typing.Type[RadioButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.RadioButton]) -> RadioButtonAutomationPeer:...
    def add_to_selection(self) -> None: ...
    def remove_from_selection(self) -> None: ...
    def select(self) -> None: ...
    @_property
    def is_selected(self) -> bool: ...
    @_property
    def selection_container(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...

class RangeBaseAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RangeBaseAutomationPeer: ...
    def __new__(cls: typing.Type[RangeBaseAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.RangeBase]) -> RangeBaseAutomationPeer:...
    def set_value(self, value: winrt.system.Double, /) -> None: ...
    @_property
    def is_read_only(self) -> bool: ...
    @_property
    def large_change(self) -> winrt.system.Double: ...
    @_property
    def maximum(self) -> winrt.system.Double: ...
    @_property
    def minimum(self) -> winrt.system.Double: ...
    @_property
    def small_change(self) -> winrt.system.Double: ...
    @_property
    def value(self) -> winrt.system.Double: ...

class RatingControlAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RatingControlAutomationPeer: ...
    def __new__(cls: typing.Type[RatingControlAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.RatingControl]) -> RatingControlAutomationPeer:...

class RepeatButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RepeatButtonAutomationPeer: ...
    def __new__(cls: typing.Type[RepeatButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.RepeatButton]) -> RepeatButtonAutomationPeer:...
    def invoke(self) -> None: ...

class RichEditBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RichEditBoxAutomationPeer: ...
    def __new__(cls: typing.Type[RichEditBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.RichEditBox]) -> RichEditBoxAutomationPeer:...

class RichTextBlockAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RichTextBlockAutomationPeer: ...
    def __new__(cls: typing.Type[RichTextBlockAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.RichTextBlock]) -> RichTextBlockAutomationPeer:...

class RichTextBlockOverflowAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RichTextBlockOverflowAutomationPeer: ...
    def __new__(cls: typing.Type[RichTextBlockOverflowAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.RichTextBlockOverflow]) -> RichTextBlockOverflowAutomationPeer:...

class ScrollBarAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ScrollBarAutomationPeer: ...
    def __new__(cls: typing.Type[ScrollBarAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.ScrollBar]) -> ScrollBarAutomationPeer:...

class ScrollViewerAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ScrollViewerAutomationPeer: ...
    def __new__(cls: typing.Type[ScrollViewerAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ScrollViewer]) -> ScrollViewerAutomationPeer:...
    def scroll(self, horizontal_amount: winrt.windows.ui.xaml.automation.ScrollAmount, vertical_amount: winrt.windows.ui.xaml.automation.ScrollAmount, /) -> None: ...
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    @_property
    def horizontally_scrollable(self) -> bool: ...
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    @_property
    def vertically_scrollable(self) -> bool: ...

class SearchBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SearchBoxAutomationPeer: ...
    def __new__(cls: typing.Type[SearchBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.SearchBox]) -> SearchBoxAutomationPeer:...

class SelectorAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SelectorAutomationPeer: ...
    def __new__(cls: typing.Type[SelectorAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.Selector]) -> SelectorAutomationPeer:...
    def get_selection(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...
    @_property
    def can_select_multiple(self) -> bool: ...
    @_property
    def is_selection_required(self) -> bool: ...

class SelectorItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SelectorItemAutomationPeer: ...
    def __new__(cls: typing.Type[SelectorItemAutomationPeer], item: typing.Optional[winrt.system.Object], parent: typing.Optional[SelectorAutomationPeer]) -> SelectorItemAutomationPeer:...
    def add_to_selection(self) -> None: ...
    def remove_from_selection(self) -> None: ...
    def select(self) -> None: ...
    @_property
    def is_selected(self) -> bool: ...
    @_property
    def selection_container(self) -> typing.Optional[winrt.windows.ui.xaml.automation.provider.IRawElementProviderSimple]: ...

class SemanticZoomAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SemanticZoomAutomationPeer: ...
    def __new__(cls: typing.Type[SemanticZoomAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.SemanticZoom]) -> SemanticZoomAutomationPeer:...
    def toggle(self) -> None: ...
    @_property
    def toggle_state(self) -> winrt.windows.ui.xaml.automation.ToggleState: ...

class SettingsFlyoutAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SettingsFlyoutAutomationPeer: ...
    def __new__(cls: typing.Type[SettingsFlyoutAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.SettingsFlyout]) -> SettingsFlyoutAutomationPeer:...

class SliderAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SliderAutomationPeer: ...
    def __new__(cls: typing.Type[SliderAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.Slider]) -> SliderAutomationPeer:...

class TextBlockAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TextBlockAutomationPeer: ...
    def __new__(cls: typing.Type[TextBlockAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.TextBlock]) -> TextBlockAutomationPeer:...

class TextBoxAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TextBoxAutomationPeer: ...
    def __new__(cls: typing.Type[TextBoxAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.TextBox]) -> TextBoxAutomationPeer:...

class ThumbAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ThumbAutomationPeer: ...
    def __new__(cls: typing.Type[ThumbAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.Thumb]) -> ThumbAutomationPeer:...

class TimePickerAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TimePickerAutomationPeer: ...
    def __new__(cls: typing.Type[TimePickerAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.TimePicker]) -> TimePickerAutomationPeer:...

class TimePickerFlyoutPresenterAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TimePickerFlyoutPresenterAutomationPeer: ...

class ToggleButtonAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToggleButtonAutomationPeer: ...
    def __new__(cls: typing.Type[ToggleButtonAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.primitives.ToggleButton]) -> ToggleButtonAutomationPeer:...
    def toggle(self) -> None: ...
    @_property
    def toggle_state(self) -> winrt.windows.ui.xaml.automation.ToggleState: ...

class ToggleMenuFlyoutItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToggleMenuFlyoutItemAutomationPeer: ...
    def __new__(cls: typing.Type[ToggleMenuFlyoutItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ToggleMenuFlyoutItem]) -> ToggleMenuFlyoutItemAutomationPeer:...
    def toggle(self) -> None: ...
    @_property
    def toggle_state(self) -> winrt.windows.ui.xaml.automation.ToggleState: ...

class ToggleSwitchAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToggleSwitchAutomationPeer: ...
    def __new__(cls: typing.Type[ToggleSwitchAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.ToggleSwitch]) -> ToggleSwitchAutomationPeer:...
    def toggle(self) -> None: ...
    @_property
    def toggle_state(self) -> winrt.windows.ui.xaml.automation.ToggleState: ...

class TreeViewItemAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TreeViewItemAutomationPeer: ...
    def __new__(cls: typing.Type[TreeViewItemAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.TreeViewItem]) -> TreeViewItemAutomationPeer:...
    def collapse(self) -> None: ...
    def expand(self) -> None: ...
    @_property
    def expand_collapse_state(self) -> winrt.windows.ui.xaml.automation.ExpandCollapseState: ...

class TreeViewListAutomationPeer(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TreeViewListAutomationPeer: ...
    def __new__(cls: typing.Type[TreeViewListAutomationPeer], owner: typing.Optional[winrt.windows.ui.xaml.controls.TreeViewList]) -> TreeViewListAutomationPeer:...

